from pathlib import Path
import environ


env = environ.Env()
environ.Env.read_env(env_file="../.env")

# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/3.2/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = "django-insecure-i=43_7ih&el3&2ouv)gk33#1=t2b6cr98m7eu7#ffnje_o3zxu"

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

ALLOWED_HOSTS = []

# Application definition

INSTALLED_APPS = [
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.messages",
    "django.contrib.staticfiles",
    "django_cas_ng",
    "app",
    "django_bootstrap5",
    "crispy_forms",
    "crispy_bootstrap5",
]

CRISPY_ALLOWED_TEMPLATE_PACKS = "bootstrap5"

CRISPY_TEMPLATE_PACK = "bootstrap5"

MIDDLEWARE = [
    "django.middleware.security.SecurityMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.middleware.common.CommonMiddleware",
    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.middleware.clickjacking.XFrameOptionsMiddleware",
    "django_cas_ng.middleware.CASMiddleware",
]

ROOT_URLCONF = "app.urls"

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [BASE_DIR / "templates"],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
            ],
        },
    },
]

# Custom User model
AUTH_USER_MODEL = "app.User"

# After successfully login redirect to home page
LOGIN_REDIRECT_URL = "/"

# After successfully logout redirect to home page
LOGOUT_REDIRECT_URL = "/"

WSGI_APPLICATION = "app.wsgi.application"


# Database
# https://docs.djangoproject.com/en/3.2/ref/settings/#databases

DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.sqlite3",
        "NAME": "db.sqlite3",
    }
}


# Password validation
# https://docs.djangoproject.com/en/3.2/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        "NAME": "django.contrib.auth.password_validation.UserAttributeSimilarityValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.MinimumLengthValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.CommonPasswordValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.NumericPasswordValidator",
    },
]


# Internationalization
# https://docs.djangoproject.com/en/3.2/topics/i18n/

LANGUAGE_CODE = "fr-FR"

TIME_ZONE = "Europe/Paris"

USE_I18N = True

USE_L10N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/3.2/howto/static-files/

STATIC_URL = "/static/"

# Default primary key field type
# https://docs.djangoproject.com/en/3.2/ref/settings/#default-auto-field

DEFAULT_AUTO_FIELD = "django.db.models.BigAutoField"

# Authentication

AUTHENTICATION_BACKENDS = [
    "django.contrib.auth.backends.ModelBackend",
    "app.backends.AppCASBackend",
]

###################################### CAS AUTH ######################################
CAS_SERVER_URL = env("CAS_SERVER_URL", default="https://cas.dev.inpt.fr")

# On crée un user si l'authentification CAS a réussi
CAS_CREATE_USER = True

CAS_LOGOUT_COMPLETELY = True

CAS_LOGIN_MSG = None

CAS_LOGGED_MSG = None

CAS_LOGIN_NEXT_PAGE = "/"

CAS_LOGOUT_NEXT_PAGE = "/"

CAS_ADMIN_PREFIX = "/adminCAS/"
######################################################################################

DATABASES["ldap"] = {
    "ENGINE": env("LDAP_ENGINE", default="ldapdb.backends.ldap"),
    "NAME": env("LDAP_NAME", default="ldap://localhost:64389"),
    "USER": env("LDAP_USER", default="cn=admin,dc=inp-net,dc=org"),
    "PASSWORD": env("LDAP_PASSWORD", default="admin"),
    "BASE_DB": env("LDAP_BASE_DB", default="dc=inp-net,dc=org"),
}

LDAP_ACCESS_SECRET = {
    'principal': {
        'uri': env("LDAP_NAME"),
        'base': env("LDAP_BASE_DB"),
        'accounts': {
            'consult': (env("LDAP_USER"), env("LDAP_PASSWORD", default="admin"))
        }
    }
}
